﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using HeuristicLab.Common;
using HeuristicLab.Encodings.RealVectorEncoding;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using HeuristicLab.PluginInfrastructure;

namespace HeuristicLab.Analysis.SolutionCaching.RealVectorEncoding {
  [NonDiscoverableType]
  [StorableClass]
  public class RealVectorEqualityComparer : EqualityComparer<RealVector> {
    public RealVectorEqualityComparer() { }
    [StorableConstructor]
    protected RealVectorEqualityComparer(bool deserializing) { }

    public override bool Equals(RealVector x, RealVector y) {
      for (int i = 0; i < x.Length; i++) {
        if (!x[i].IsAlmost(y[i])) return false;
      }
      return true;
    }

    public override int GetHashCode(RealVector obj) {
      unchecked {
        int hash = 17;
        for (int i = 0; i < obj.Length; i++) {
          hash = hash * 23 + obj[i].GetHashCode();
        }
        return hash;
      }
    }
  }
}
